<?php

/**
 * @file
 * Contains \Drupal\file\Plugin\field\formatter\RSSEnclosureFormatter.
 */

namespace Drupal\file\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'file_rss_enclosure' formatter.
 *
 * @FieldFormatter(
 *   id = "file_rss_enclosure",
 *   label = @Translation("RSS enclosure"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class RSSEnclosureFormatter extends FileFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items) {
    $entity = $items->getEntity();
    // Add the first file as an enclosure to the RSS item. RSS allows only one
    // enclosure per item. See: http://en.wikipedia.org/wiki/RSS_enclosure
    foreach ($items as $item) {
      if ($item->isDisplayed() && $item->entity) {
        $file = $item->entity;
        $entity->rss_elements[] = array(
          'key' => 'enclosure',
          'attributes' => array(
            'url' => file_create_url($file->getFileUri()),
            'length' => $file->getSize(),
            'type' => $file->getMimeType(),
          ),
        );
        break;
      }
    }

  }

}
